@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-use Try::Chain qw( $call_m $fetch_i $fetch_ei $fetch_k $fetch_ek );
+use Try::Chain qw( $call_m $call_em $fetch_i $fetch_ei $fetch_k $fetch_ek );
 
 our $VERSION = '0.001';
 # create an object
@@ -33,6 +33,11 @@ my $counter = 0;
     my $result = __PACKAGE__->new->$call_m('string');
     () = print ++$counter, $result || 'undef', "\n";
 }
+# prints string
+{
+    my $result = __PACKAGE__->new->$call_em('string');
+    () = print ++$counter, $result || 'undef', "\n";
+}
 # prints last elemtent of list
 {
     my $result = __PACKAGE__->new->$call_m('list');
@@ -64,6 +69,16 @@ my $counter = 0;
     my $result = __PACKAGE__->new->nothing->$call_m('string');
     () = print ++$counter, $result || 'undef', "\n";
 }
+# prints undef because of nothing
+{
+    my $result = __PACKAGE__->new->nothing->$call_em('string');
+    () = print ++$counter, $result || 'undef', "\n";
+}
+# prints undef because of not existing method
+{
+    my $result = __PACKAGE__->new->$call_em('string1');
+    () = print ++$counter, $result || 'undef', "\n";
+}
 {
     my $result = __PACKAGE__->new->nothing->$call_m('list');
     () = print ++$counter, $result || 'undef', "\n";
@@ -92,14 +107,17 @@ __END__
 
 Output:
 1foo
-2baz
-3item
+2foo
+3baz
 4item
-5value
+5item
 6value
-7undef
+7value
 8undef
 9undef
 10undef
 11undef
 12undef
+13undef
+14undef
+15undef
