@@ -5,12 +5,12 @@ use warnings;
 use parent qw(Exporter);
 use Try::Tiny qw(try catch finally);
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 our @EXPORT_OK = qw(
     try catch finally
     try_chain
-    $call_m
+    $call_m  $call_em
     $fetch_i $fetch_ei
     $fetch_k $fetch_ek
 );
@@ -45,6 +45,12 @@ our $call_m = sub { ## no critic (PackageVars)
     return $self ? $self->$method(@more) : ();
 };
 
+our $call_em = sub { ## no critic (PackageVars)
+    my ( $self, $method, @more ) = @_;
+
+    return $self && $self->can($method) ? $self->$method(@more) : ();
+};
+
 our $fetch_i = sub { ## no critic (PackageVars)
     my ( $array_ref, $index ) = @_;
 
@@ -79,7 +85,7 @@ Try::Chain - Call method, hash and/or array chains with break on undef
 
 =head1 VERSION
 
-0.004
+0.005
 
 =head1 SYNOPSIS
 
@@ -107,6 +113,10 @@ implemented here to call a complete chain or break
 
 implemented here to call a method or break
 
+=item $call_em
+
+implemented here to call an existing method or break
+
 =item $fetch_i
 
 implemented here to fetch an array index or break
@@ -130,7 +140,7 @@ Import what needed. The following code describes the full import:
     use Try::Chain qw(
         try catch finally
         try_chain
-        $call_m
+        $call_m  $call_em
         $fetch_i $fetch_ei
         $fetch_k $fetch_ek
     );
@@ -254,14 +264,26 @@ Calls the whole try block, breaks and ignores undef errors.
 
 Calls the next method if possible.
 
+=head2 sub $call_em
+
+Calls the next method if possible and method exists.
+
 =head2 sub $fetch_i
 
 Calls the next index of an array reference if possible.
 
+=head2 sub $fetch_ei
+
+Calls the next index of an array reference if possible and index exists.
+
 =head2 sub $fetch_k
 
 Calls the next key of a hash reference if possible.
 
+=head2 sub $fetch_ek
+
+Calls the next key of a hash reference if possible and key exists.
+
 =head1 DIAGNOSTICS
 
 none
